@@ -184,14 +184,16 @@ def loaddoc(topic, subdir=None):
     return loader
 
 internalstable = sorted([
-    (['bundles'], _('container for exchange of repository data'),
+    (['bundles'], _('Bundles'),
      loaddoc('bundles', subdir='internals')),
-    (['changegroups'], _('representation of revlog data'),
+    (['changegroups'], _('Changegroups'),
      loaddoc('changegroups', subdir='internals')),
-    (['requirements'], _('repository requirements'),
+    (['requirements'], _('Repository Requirements'),
      loaddoc('requirements', subdir='internals')),
-    (['revlogs'], _('revision storage mechanism'),
+    (['revlogs'], _('Revision Logs'),
      loaddoc('revlogs', subdir='internals')),
+    (['wireprotocol'], _('Wire Protocol'),
+     loaddoc('wireprotocol', subdir='internals')),
 ])
 
 def internalshelp(ui):
@@ -208,14 +210,12 @@ helptable = sorted([
     (["patterns"], _("File Name Patterns"), loaddoc('patterns')),
     (['environment', 'env'], _('Environment Variables'),
      loaddoc('environment')),
-    (['revisions', 'revs'], _('Specifying Single Revisions'),
-     loaddoc('revisions')),
-    (['multirevs', 'mrevs'], _('Specifying Multiple Revisions'),
-     loaddoc('multirevs')),
-    (['revsets', 'revset'], _("Specifying Revision Sets"), loaddoc('revsets')),
+    (['revisions', 'revs', 'revsets', 'revset', 'multirevs', 'mrevs'],
+      _('Specifying Revisions'), loaddoc('revisions')),
     (['filesets', 'fileset'], _("Specifying File Sets"), loaddoc('filesets')),
     (['diffs'], _('Diff Formats'), loaddoc('diffs')),
-    (['merge-tools', 'mergetools'], _('Merge Tools'), loaddoc('merge-tools')),
+    (['merge-tools', 'mergetools', 'mergetool'], _('Merge Tools'),
+     loaddoc('merge-tools')),
     (['templating', 'templates', 'template', 'style'], _('Template Usage'),
      loaddoc('templates')),
     (['urls'], _('URL Paths'), loaddoc('urls')),
@@ -279,7 +279,7 @@ def addtopicsymbols(topic, marker, symbols, dedent=False):
 addtopicsymbols('filesets', '.. predicatesmarker', fileset.symbols)
 addtopicsymbols('merge-tools', '.. internaltoolsmarker',
                 filemerge.internalsdoc)
-addtopicsymbols('revsets', '.. predicatesmarker', revset.symbols)
+addtopicsymbols('revisions', '.. predicatesmarker', revset.symbols)
 addtopicsymbols('templates', '.. keywordsmarker', templatekw.keywords)
 addtopicsymbols('templates', '.. filtersmarker', templatefilters.filters)
 addtopicsymbols('templates', '.. functionsmarker', templater.funcs)
@@ -356,8 +356,8 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
             mod = extensions.find(name)
             doc = gettext(mod.__doc__) or ''
             if '\n' in doc.strip():
-                msg = _('(use "hg help -e %s" to show help for '
-                        'the %s extension)') % (name, name)
+                msg = _("(use 'hg help -e %s' to show help for "
+                        "the %s extension)") % (name, name)
                 rst.append('\n%s\n' % msg)
         except KeyError:
             pass
@@ -372,7 +372,7 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
 
         if not ui.verbose:
             if not full:
-                rst.append(_('\n(use "hg %s -h" to show more help)\n')
+                rst.append(_("\n(use 'hg %s -h' to show more help)\n")
                            % name)
             elif not ui.quiet:
                 rst.append(_('\n(some details hidden, use --verbose '
@@ -448,21 +448,21 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
             rst.append('\n%s\n' % optrst(_("global options"),
                                          commands.globalopts, ui.verbose))
             if name == 'shortlist':
-                rst.append(_('\n(use "hg help" for the full list '
-                             'of commands)\n'))
+                rst.append(_("\n(use 'hg help' for the full list "
+                             "of commands)\n"))
         else:
             if name == 'shortlist':
-                rst.append(_('\n(use "hg help" for the full list of commands '
-                             'or "hg -v" for details)\n'))
+                rst.append(_("\n(use 'hg help' for the full list of commands "
+                             "or 'hg -v' for details)\n"))
             elif name and not full:
-                rst.append(_('\n(use "hg help %s" to show the full help '
-                             'text)\n') % name)
+                rst.append(_("\n(use 'hg help %s' to show the full help "
+                             "text)\n") % name)
             elif name and cmds and name in cmds.keys():
-                rst.append(_('\n(use "hg help -v -e %s" to show built-in '
-                             'aliases and global options)\n') % name)
+                rst.append(_("\n(use 'hg help -v -e %s' to show built-in "
+                             "aliases and global options)\n") % name)
             else:
-                rst.append(_('\n(use "hg help -v%s" to show built-in aliases '
-                             'and global options)\n')
+                rst.append(_("\n(use 'hg help -v%s' to show built-in aliases "
+                             "and global options)\n")
                            % (name and " " + name or ""))
         return rst
 
@@ -496,8 +496,8 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
 
         try:
             cmdutil.findcmd(name, commands.table)
-            rst.append(_('\nuse "hg help -c %s" to see help for '
-                       'the %s command\n') % (name, name))
+            rst.append(_("\nuse 'hg help -c %s' to see help for "
+                       "the %s command\n") % (name, name))
         except error.UnknownCommand:
             pass
         return rst
@@ -534,8 +534,8 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
             modcmds = set([c.partition('|')[0] for c in ct])
             rst.extend(helplist(modcmds.__contains__))
         else:
-            rst.append(_('(use "hg help extensions" for information on enabling'
-                       ' extensions)\n'))
+            rst.append(_("(use 'hg help extensions' for information on enabling"
+                       " extensions)\n"))
         return rst
 
     def helpextcmd(name, subtopic=None):
@@ -547,8 +547,8 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
                               "extension:") % cmd, {ext: doc}, indent=4,
                        showdeprecated=True)
         rst.append('\n')
-        rst.append(_('(use "hg help extensions" for information on enabling '
-                   'extensions)\n'))
+        rst.append(_("(use 'hg help extensions' for information on enabling "
+                   "extensions)\n"))
         return rst
 
 
@@ -573,7 +573,7 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
                 rst.append('\n')
         if not rst:
             msg = _('no matches')
-            hint = _('try "hg help" for a list of topics')
+            hint = _("try 'hg help' for a list of topics")
             raise error.Abort(msg, hint=hint)
     elif name and name != 'shortlist':
         queries = []
@@ -596,7 +596,7 @@ def help_(ui, name, unknowncmd=False, full=True, subtopic=None, **opts):
                 raise error.UnknownCommand(name)
             else:
                 msg = _('no such help topic: %s') % name
-                hint = _('try "hg help --keyword %s"') % name
+                hint = _("try 'hg help --keyword %s'") % name
                 raise error.Abort(msg, hint=hint)
     else:
         # program name
